pub async fn evaluate(
evaluator: &dyn Evaluator,
dataset: &Dataset,
predictions: &[String],
) -> Result<EvalReport, SynapticError>Expand description
Evaluate predictions against a dataset using an evaluator.
Each prediction is evaluated against the corresponding dataset item. The number of predictions must match the number of dataset items.