pub struct RegexMatchEvaluator { /* private fields */ }Expand description
Evaluator that checks whether the prediction matches a regex pattern.
Implementations
Sourceimpl RegexMatchEvaluator
impl RegexMatchEvaluator
Sourcepub fn new(pattern: &str) -> Result<Self, SynapticError>
pub fn new(pattern: &str) -> Result<Self, SynapticError>
Create a new regex match evaluator with the given pattern.
Returns an error if the pattern is not a valid regex.